====================
Citation Information
====================

References
##########

``YAPC`` is developed with the goal of supporting and simplifying science
applications for the NASA ICESat-2 mission. This work is developed in
conjunction with other ICESat-2 projects.

Contributors
############

.. include:: ../../../CONTRIBUTORS.rst

Development
###########

This is an open source project.
We welcome any help in maintaining and developing the software and documentation.
Anyone at any career stage and with any level of coding experience can contribute.
Please see the `Contribution Guidelines <./Contributing.html>`_ for more information.

Problem Reports
###############

If you have found a problem in these programs, or you would like to suggest an improvement or modification,
please submit a `GitHub issue <https://github.com/tsutterley/yapc/issues>`_ and we will get back to you.

Dependencies
############

This software is also dependent on other commonly used Python packages:

- `numpy: Scientific Computing Tools For Python <https://numpy.org>`_
- `cython: C-extensions for Python <http://cython.org/>`_
- `h5py: Python interface for Hierarchal Data Format 5 (HDF5) <http://h5py.org>`_
- `scikit-learn: Machine Learning in Python <https://scikit-learn.org/stable/index.html>`_
- `future: Compatibility layer between Python 2 and Python 3 <http://python-future.org/>`_

Credits
#######

``YAPC`` was devised and is being developed by `Jeff Lee <https://science.gsfc.nasa.gov/sed/bio/jeffrey.e.lee>`_,
Software Development Lead in the Cryospheric Sciences Laboratory at NASA Goddard Space Flight Center.

Disclaimer
##########

This package includes software developed at NASA Goddard Space Flight Center (GSFC) and
the University of Washington Applied Physics Laboratory (UW-APL).
It is not sponsored or maintained by the Universities Space Research Association (USRA) or NASA.
